==> qtjambi-qt3drender-5.15.9-sources.jar: io/qt/qt3d/render/QSubtreeEnabler.java <==
package io.qt.qt3d.render;


/**
 * <p>Enables or disables entire subtrees of framegraph nodes</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qsubtreeenabler.html">Qt3DRender::QSubtreeEnabler</a></p>
 */
public class QSubtreeEnabler extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSubtreeEnabler.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qsubtreeenabler.html#Enablement-enum">Qt3DRender::QSubtreeEnabler::Enablement</a></p>
     */
    public enum Enablement implements io.qt.QtEnumerator {
        Persistent(0),
        SingleShot(1);

        private Enablement(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static Enablement resolve(int value) {
            switch (value) {
            case 0: return Persistent;
            case 1: return SingleShot;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsubtreeenabler.html#enablement-prop">Qt3DRender::QSubtreeEnabler::enablementChanged(Qt3DRender::QSubtreeEnabler::Enablement)</a></p>
     */
    @io.qt.QtPropertyNotify(name="enablement")
    public final Signal1<io.qt.qt3d.render.QSubtreeEnabler.Enablement> enablementChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QSubtreeEnabler(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSubtreeEnabler() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QSubtreeEnabler(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSubtreeEnabler instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#createNodeCreationChange">Qt3DCore::QNode::createNodeCreationChange()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange() throws io.qt.QNoImplementationException {
        return createNodeCreationChange_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsubtreeenabler.html#enablement-prop">Qt3DRender::QSubtreeEnabler::enablement()const</a></p>
     */
    @io.qt.QtPropertyReader(name="enablement")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QSubtreeEnabler.Enablement enablement(){
        return io.qt.qt3d.render.QSubtreeEnabler.Enablement.resolve(enablement_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int enablement_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsubtreeenabler.html#requestUpdate">Qt3DRender::QSubtreeEnabler::requestUpdate()</a></p>
     */
    public final void requestUpdate(){
        requestUpdate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void requestUpdate_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsubtreeenabler.html#enablement-prop">Qt3DRender::QSubtreeEnabler::setEnablement(Qt3DRender::QSubtreeEnabler::Enablement)</a></p>
     */
    @io.qt.QtPropertyWriter(name="enablement")
    @io.qt.QtUninvokable
    public final void setEnablement(io.qt.qt3d.render.QSubtreeEnabler.Enablement enablement){
        setEnablement_native_Qt3DRender_QSubtreeEnabler_Enablement(QtJambi_LibraryUtilities.internal.nativeId(this), enablement.value());
    }
    
    @io.qt.QtUninvokable
    private native void setEnablement_native_Qt3DRender_QSubtreeEnabler_Enablement(long __this__nativeId, int enablement);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSubtreeEnabler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSubtreeEnabler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSubtreeEnabler instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QSubtreeEnabler.java <==
package io.qt.qt3d.render;


/**
 * <p>Enables or disables entire subtrees of framegraph nodes</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qsubtreeenabler.html">Qt3DRender::QSubtreeEnabler</a></p>
 */
public class QSubtreeEnabler extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSubtreeEnabler.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qsubtreeenabler.html#Enablement-enum">Qt3DRender::QSubtreeEnabler::Enablement</a></p>
     */
    public enum Enablement implements io.qt.QtEnumerator {
        Persistent(0),
        SingleShot(1);

        private Enablement(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static Enablement resolve(int value) {
            switch (value) {
            case 0: return Persistent;
            case 1: return SingleShot;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsubtreeenabler.html#enablement-prop">Qt3DRender::QSubtreeEnabler::enablementChanged(Qt3DRender::QSubtreeEnabler::Enablement)</a></p>
     */
    @io.qt.QtPropertyNotify(name="enablement")
    public final Signal1<io.qt.qt3d.render.QSubtreeEnabler.Enablement> enablementChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QSubtreeEnabler(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSubtreeEnabler() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QSubtreeEnabler(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSubtreeEnabler instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#createNodeCreationChange">Qt3DCore::QNode::createNodeCreationChange()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange() throws io.qt.QNoImplementationException {
        return createNodeCreationChange_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsubtreeenabler.html#enablement-prop">Qt3DRender::QSubtreeEnabler::enablement()const</a></p>
     */
    @io.qt.QtPropertyReader(name="enablement")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QSubtreeEnabler.Enablement enablement(){
        return io.qt.qt3d.render.QSubtreeEnabler.Enablement.resolve(enablement_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int enablement_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsubtreeenabler.html#requestUpdate">Qt3DRender::QSubtreeEnabler::requestUpdate()</a></p>
     */
    public final void requestUpdate(){
        requestUpdate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void requestUpdate_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsubtreeenabler.html#enablement-prop">Qt3DRender::QSubtreeEnabler::setEnablement(Qt3DRender::QSubtreeEnabler::Enablement)</a></p>
     */
    @io.qt.QtPropertyWriter(name="enablement")
    @io.qt.QtUninvokable
    public final void setEnablement(io.qt.qt3d.render.QSubtreeEnabler.Enablement enablement){
        setEnablement_native_Qt3DRender_QSubtreeEnabler_Enablement(QtJambi_LibraryUtilities.internal.nativeId(this), enablement.value());
    }
    
    @io.qt.QtUninvokable
    private native void setEnablement_native_Qt3DRender_QSubtreeEnabler_Enablement(long __this__nativeId, int enablement);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSubtreeEnabler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSubtreeEnabler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSubtreeEnabler instance, QDeclarativeConstructor constructor);
    
}
